==> snbl-toolbox-2016.10.19.tar.gz: snbl-toolbox-2016.10.19/SNBLToolBox/ui/ui_wdarth.py <==
# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WDarth(object):
    def setupUi(self, WDarth):
        WDarth.setObjectName("WDarth")
        WDarth.resize(699, 336)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/darth"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WDarth.setWindowIcon(icon)
        WDarth.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(WDarth)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(WDarth)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.folderLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.folderLineEdit.setObjectName("folderLineEdit")
        self.horizontalLayout.addWidget(self.folderLineEdit)
        self.folderButton = QtWidgets.QPushButton(self.groupBox)
        self.folderButton.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/folder"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.folderButton.setIcon(icon1)
        self.folderButton.setObjectName("folderButton")
        self.horizontalLayout.addWidget(self.folderButton)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_2.addWidget(self.label_3)
        self.xLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.xLineEdit.setMaxLength(4)
        self.xLineEdit.setObjectName("xLineEdit")
        self.horizontalLayout_2.addWidget(self.xLineEdit)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        self.yLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.yLineEdit.setMaxLength(4)
        self.yLineEdit.setObjectName("yLineEdit")
        self.horizontalLayout_2.addWidget(self.yLineEdit)
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_2.addWidget(self.label_5)
        self.zLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.zLineEdit.setMaxLength(4)
        self.zLineEdit.setObjectName("zLineEdit")
        self.horizontalLayout_2.addWidget(self.zLineEdit)
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_2.addWidget(self.label_6)
        self.dQLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.dQLineEdit.setMaxLength(4)
        self.dQLineEdit.setObjectName("dQLineEdit")
        self.horizontalLayout_2.addWidget(self.dQLineEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.lorentzCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.lorentzCheckBox.setObjectName("lorentzCheckBox")
        self.verticalLayout.addWidget(self.lorentzCheckBox)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.runButton = QtWidgets.QPushButton(self.groupBox)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/run"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.runButton.setIcon(icon2)
        self.runButton.setObjectName("runButton")
        self.horizontalLayout_3.addWidget(self.runButton)
        self.stopButton = QtWidgets.QPushButton(self.groupBox)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/stop"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.stopButton.setIcon(icon3)
        self.stopButton.setObjectName("stopButton")
        self.horizontalLayout_3.addWidget(self.stopButton)
        self.runProgressBar = QtWidgets.QProgressBar(self.groupBox)
        self.runProgressBar.setProperty("value", 0)
        self.runProgressBar.setObjectName("runProgressBar")
        self.horizontalLayout_3.addWidget(self.runProgressBar)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.verticalLayout_3.addWidget(self.groupBox)

        self.retranslateUi(WDarth)
        QtCore.QMetaObject.connectSlotsByName(WDarth)

    def retranslateUi(self, WDarth):
        _translate = QtCore.QCoreApplication.translate
        WDarth.setWindowTitle(_translate("WDarth", "Darth Vader\'s Chimera"))
        self.groupBox.setTitle(_translate("WDarth", "Create ccp4 map"))
        self.label.setText(_translate("WDarth", "Folder with processed by Crysalis cbf files:"))
        self.folderLineEdit.setToolTip(_translate("WDarth", "<html><head/><body><p>Choose here the folder where there are your data sets</p></body></html>"))
        self.label_2.setText(_translate("WDarth", "Volume size:"))
        self.label_3.setText(_translate("WDarth", "x"))
        self.xLineEdit.setText(_translate("WDarth", "256"))
        self.label_4.setText(_translate("WDarth", "y"))
        self.yLineEdit.setText(_translate("WDarth", "256"))
        self.label_5.setText(_translate("WDarth", "z"))
        self.zLineEdit.setText(_translate("WDarth", "256"))
        self.label_6.setText(_translate("WDarth", "dQ"))
        self.dQLineEdit.setText(_translate("WDarth", "0.6"))
        self.lorentzCheckBox.setText(_translate("WDarth", "Apply Lorentz corrections"))
        self.runButton.setText(_translate("WDarth", "Run"))
        self.stopButton.setText(_translate("WDarth", "Stop"))

from . import resources_rc

==> snbl-toolbox-2017.3.1.tar.gz: snbl-toolbox-2017.3.1/SNBLToolBox/ui/ui_wdarth.py <==
# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WDarth(object):
    def setupUi(self, WDarth):
        WDarth.setObjectName("WDarth")
        WDarth.resize(652, 513)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/darth"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WDarth.setWindowIcon(icon)
        WDarth.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(WDarth)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(WDarth)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.folderLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.folderLineEdit.setObjectName("folderLineEdit")
        self.horizontalLayout.addWidget(self.folderLineEdit)
        self.folderButton = QtWidgets.QPushButton(self.groupBox)
        self.folderButton.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/folder"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.folderButton.setIcon(icon1)
        self.folderButton.setObjectName("folderButton")
        self.horizontalLayout.addWidget(self.folderButton)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.volumeCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.volumeCheckBox.setChecked(True)
        self.volumeCheckBox.setObjectName("volumeCheckBox")
        self.horizontalLayout_2.addWidget(self.volumeCheckBox)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_2.addWidget(self.label_3)
        self.xLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.xLineEdit.setMaxLength(4)
        self.xLineEdit.setObjectName("xLineEdit")
        self.horizontalLayout_2.addWidget(self.xLineEdit)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        self.yLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.yLineEdit.setMaxLength(4)
        self.yLineEdit.setObjectName("yLineEdit")
        self.horizontalLayout_2.addWidget(self.yLineEdit)
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_2.addWidget(self.label_5)
        self.zLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.zLineEdit.setMaxLength(4)
        self.zLineEdit.setObjectName("zLineEdit")
        self.horizontalLayout_2.addWidget(self.zLineEdit)
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_2.addWidget(self.label_6)
        self.dQLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.dQLineEdit.setMaxLength(4)
        self.dQLineEdit.setObjectName("dQLineEdit")
        self.horizontalLayout_2.addWidget(self.dQLineEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.treeLayers = MTreeWidget(self.groupBox)
        self.treeLayers.setObjectName("treeLayers")
        self.verticalLayout.addWidget(self.treeLayers)
        self.lorentzCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.lorentzCheckBox.setObjectName("lorentzCheckBox")
        self.verticalLayout.addWidget(self.lorentzCheckBox)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_4.addWidget(self.label_2)
        self.editDownsample = QtWidgets.QLineEdit(self.groupBox)
        self.editDownsample.setObjectName("editDownsample")
        self.horizontalLayout_4.addWidget(self.editDownsample)
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_4.addWidget(self.label_7)
        self.editScale = QtWidgets.QLineEdit(self.groupBox)
        self.editScale.setObjectName("editScale")
        self.horizontalLayout_4.addWidget(self.editScale)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.runButton = QtWidgets.QPushButton(self.groupBox)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/run"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.runButton.setIcon(icon2)
        self.runButton.setObjectName("runButton")
        self.horizontalLayout_3.addWidget(self.runButton)
        self.stopButton = QtWidgets.QPushButton(self.groupBox)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/stop"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.stopButton.setIcon(icon3)
        self.stopButton.setObjectName("stopButton")
        self.horizontalLayout_3.addWidget(self.stopButton)
        self.runProgressBar = QtWidgets.QProgressBar(self.groupBox)
        self.runProgressBar.setProperty("value", 0)
        self.runProgressBar.setObjectName("runProgressBar")
        self.horizontalLayout_3.addWidget(self.runProgressBar)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.verticalLayout_3.addWidget(self.groupBox)

        self.retranslateUi(WDarth)
        QtCore.QMetaObject.connectSlotsByName(WDarth)

    def retranslateUi(self, WDarth):
        _translate = QtCore.QCoreApplication.translate
        WDarth.setWindowTitle(_translate("WDarth", "Darth Vader\'s Chimera"))
        self.groupBox.setTitle(_translate("WDarth", "Create ccp4 map"))
        self.label.setText(_translate("WDarth", "Folder with processed by Crysalis cbf files:"))
        self.folderLineEdit.setToolTip(_translate("WDarth", "<html><head/><body><p>Choose here the folder where there are your data sets</p></body></html>"))
        self.volumeCheckBox.setText(_translate("WDarth", "Reconstruct volume:"))
        self.label_3.setText(_translate("WDarth", "x"))
        self.xLineEdit.setText(_translate("WDarth", "256"))
        self.label_4.setText(_translate("WDarth", "y"))
        self.yLineEdit.setText(_translate("WDarth", "256"))
        self.label_5.setText(_translate("WDarth", "z"))
        self.zLineEdit.setText(_translate("WDarth", "256"))
        self.label_6.setText(_translate("WDarth", "dQ"))
        self.dQLineEdit.setText(_translate("WDarth", "0.6"))
        self.treeLayers.headerItem().setText(0, _translate("WDarth", "hkl_1"))
        self.treeLayers.headerItem().setText(1, _translate("WDarth", "hkl_2"))
        self.treeLayers.headerItem().setText(2, _translate("WDarth", "hkl_c"))
        self.treeLayers.headerItem().setText(3, _translate("WDarth", "Qmax"))
        self.treeLayers.headerItem().setText(4, _translate("WDarth", "thickness"))
        self.lorentzCheckBox.setText(_translate("WDarth", "Apply Lorentz corrections"))
        self.label_2.setText(_translate("WDarth", "Downsample"))
        self.label_7.setText(_translate("WDarth", "Scale"))
        self.runButton.setText(_translate("WDarth", "Run"))
        self.stopButton.setText(_translate("WDarth", "Stop"))

from ..mtreewidget import MTreeWidget
from . import resources_rc
